==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Social</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembre-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembre-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutos depois</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora depois</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas depois</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Agendar Lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 às %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Um dia antes do início</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Fechar</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Lembre-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Lembre-me mais tarde</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Agendar Lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 às %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Hoje</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Amanhã</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabalho</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Social</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Um dia antes do início</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Lembre-me amanhã</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembre-me mais tarde</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutos depois</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora depois</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas depois</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Agendar Lembrete</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 às %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
